@@ -272,7 +272,7 @@ class BrailleGenerator(generator.Generator):
 
         # Radio button group names are treated separately from the
         # ancestors.  However, they can appear in the ancestry as a
-        # labeled panel.  So, we need to exlude the first one of
+        # labeled panel.  So, we need to exclude the first one of
         # these things we come across.  See also the
         # generator.py:_generateRadioButtonGroup method that is
         # used to find the radio button group name.
@@ -345,6 +345,24 @@ class BrailleGenerator(generator.Generator):
 
         return result
 
+    def _generateStatusBar(self, obj, **args):
+        statusBar = self._script.utilities.statusBar(obj)
+        if not statusBar:
+            return []
+
+        items = self._script.utilities.statusBarItems(obj)
+        if not items or items == [statusBar]:
+            return []
+
+        result = []
+        for child in items:
+            childResult = self.generate(child, includeContext=False)
+            if childResult:
+                result.extend(childResult)
+                result.append(braille.Region(" "))
+
+        return result
+
     def _generateListBoxItemWidgets(self, obj, **args):
         widgetRoles = [pyatspi.ROLE_CHECK_BOX,
                        pyatspi.ROLE_COMBO_BOX,
