@@ -79,8 +79,11 @@ WHERE_AM_I_BASIC = _("Performs the basic where am I operation.")
 WHERE_AM_I_DETAILED = _("Performs the detailed where am I operation.")
 
 # Translators: This is the description of a dedicated command to speak the
-# selected text (if any) in a document.
-WHERE_AM_I_SELECTED_TEXT = _("Speaks the selected text.")
+# current selection / highlighted object(s). For instance, in a text object,
+# "selection" refers to the selected/highlighted text. In a spreadsheet, it
+# refers to the selected/highlighted cells. In an file manager, it refers to
+# the selected/highlighted icons. Etc.
+WHERE_AM_I_SELECTION = _("Speaks the current selection.")
 
 # Translators: This is the description of a dedicated command to speak details
 # about a link, such as the uri and type of link.
@@ -528,6 +531,11 @@ PRESENT_CURRENT_TIME = _("Present current time.")
 # braille.
 PRESENT_CURRENT_DATE = _("Present current date.")
 
+# Translators: Orca has a command to present the pixel size and location of
+# the current object. This string is how this command is described in the list
+# of keyboard shortcuts.
+PRESENT_SIZE_AND_POSITION = _("Present size and location of current object.")
+
 # Translators: Orca normally intercepts all keyboard commands and only passes
 # them along to the current application when they are not Orca commands. This
 # command causes the next command issued to be passed along to the current
@@ -1003,12 +1011,25 @@ TABLE_CELL_RIGHT = _("Goes right one cell.")
 # Translators: this is for navigating among table cells in a document.
 TABLE_CELL_UP = _("Goes up one cell.")
 
+# Translators: When presenting the content of a line on a web page, Orca by
+# default presents the full line, including any links or form fields on that
+# line, in order to reflect the on-screen layout as seen by sighted users.
+# Not all users like this presentation, however, and prefer to have objects
+# treated as if they were on individual lines, such as is done by Windows
+# screen readers, so that unrelated objects (e.g. links in a navbar) are not
+# all jumbled together. As a result, this is now configurable. If layout mode
+# is enabled, Orca will present the full line as it appears on the screen; if
+# it is disabled, Orca will treat each object as if it were on a separate line,
+# both for presentation and navigation. This string is associated with the Orca
+# command to manually toggle layout mode on/off.
+TOGGLE_LAYOUT_MODE = _("Toggles layout mode.")
+
 # Translators: Orca has a number of commands that override the default
 # behavior within an application. For instance, on a web page, "h" moves
 # you to the next heading. What should happen when you press an "h" in
 # an entry on a web page depends: If you want to resume reading content,
 # "h" should move to the next heading; if you want to enter text, "h"
-# should not not move you to the next heading. Similarly, if you are
+# should not move you to the next heading. Similarly, if you are
 # at the bottom of an entry and press Down arrow, should you leave the
 # entry? Again, it depends on if you want to resume reading content or
 # if you are editing the text in the entry. Because Orca doesn't know
