@@ -236,6 +236,7 @@ class Generator:
             msg = '%s GENERATOR: Starting generation for %s' % (self._mode.upper(), obj)
             debug.println(debug.LEVEL_INFO, msg, True)
 
+            debuginfo = lambda x: self._resultElementToString(x, False)
             assert(formatting)
             while True:
                 currentTime = time.time()
@@ -253,9 +254,11 @@ class Generator:
                         break
                     globalsDict[arg] = self._methodsDict[arg](obj, **args)
                     duration = "%.4f" % (time.time() - currentTime)
-                    debug.println(debug.LEVEL_ALL,
-                                  "%sGENERATION TIME: %s  ---->  %s=%s" \
-                                  % (' ' * 18, duration, arg, repr(globalsDict[arg])))
+                    if isinstance(globalsDict[arg], list):
+                        stringResult = " ".join(filter(lambda x: x, map(debuginfo, globalsDict[arg])))
+                        debug.println(debug.LEVEL_ALL,
+                                      "%sGENERATION TIME: %s  ---->  %s=[%s]" \
+                                      % (" " * 18, duration, arg, stringResult))
 
         except:
             debug.printException(debug.LEVEL_SEVERE)
@@ -263,15 +266,26 @@ class Generator:
 
         duration = "%.4f" % (time.time() - startTime)
         debug.println(debug.LEVEL_ALL, "%sCOMPLETION TIME: %s" % (' ' * 18, duration))
-        debug.println(debug.LEVEL_ALL, "%s GENERATOR: Results:" % self._mode.upper(), True)
-        for element in result:
-            debug.println(debug.LEVEL_ALL, "%s%s" % (' ' * 18, element))
-
+        self._debugResultInfo(result)
         if args.get('isProgressBarUpdate') and result:
             self.setProgressBarUpdateTimeAndValue(obj)
 
         return result
 
+    def _resultElementToString(self, element, includeAll=True):
+        if not includeAll:
+            return str(element)
+
+        return "\n%s'%s'" % (" " * 18, element)
+
+    def _debugResultInfo(self, result):
+        if debug.LEVEL_ALL < debug.debugLevel:
+            return
+
+        info = "%s%s GENERATOR: Results: " % (" " * 18, self._mode.upper())
+        info += "%s" % " ".join(map(self._resultElementToString, result))
+        debug.println(debug.LEVEL_ALL, info)
+
     #####################################################################
     #                                                                   #
     # Name, role, and label information                                 #
@@ -287,6 +301,13 @@ class Generator:
         # Subclasses must override this.
         return []
 
+    def _fallBackOnDescriptionForName(self, obj, **args):
+        role = args.get('role', obj.getRole())
+        if role == pyatspi.ROLE_LABEL:
+            return False
+
+        return True
+
     def _generateName(self, obj, **args):
         """Returns an array of strings for use by speech and braille that
         represent the name of the object.  If the object is directly
@@ -306,7 +327,7 @@ class Generator:
         name = obj.name
         if name:
             result.append(name)
-        else:
+        elif self._fallBackOnDescriptionForName(obj, **args):
             try:
                 description = obj.description
             except (LookupError, RuntimeError):
@@ -438,6 +459,11 @@ class Generator:
             result.append(label)
         return result
 
+    def generateStatusBar(self, obj, **args):
+        """Returns an array of strings that represent a status bar."""
+
+        return self._generateStatusBar(obj, **args)
+
     #####################################################################
     #                                                                   #
     # Image information                                                 #
@@ -661,6 +687,9 @@ class Generator:
            or obj.getRole() == pyatspi.ROLE_CHECK_MENU_ITEM:
             return self._generateCheckedState(obj, **args)
 
+        if obj.getState().contains(pyatspi.STATE_CHECKED):
+            return self._generateCheckedState(obj, **args)
+
         return []
 
     def _generateMenuItemCheckedState(self, obj, **args):
@@ -775,6 +804,18 @@ class Generator:
         result.append(text)
         return result
 
+    def _generateSortOrder(self, obj, **args):
+        if not self._script.utilities.isSorted(obj):
+            return []
+
+        if self._script.utilities.isAscending(obj):
+            return [object_properties.SORT_ORDER_ASCENDING]
+
+        if self._script.utilities.isDescending(obj):
+            return [object_properties.SORT_ORDER_DESCENDING]
+
+        return [object_properties.SORT_ORDER_OTHER]
+
     def _generateTableCell2ChildLabel(self, obj, **args):
         """Returns an array of strings for use by speech and braille for the
         label of a toggle in a table cell that has a special 2 child
@@ -1023,6 +1064,9 @@ class Generator:
             value = self._script.utilities.getComboBoxValue(obj)
             return [value]
 
+        if role == pyatspi.ROLE_SEPARATOR and not obj.getState().contains(pyatspi.STATE_FOCUSED):
+            return []
+
         return [self._script.utilities.textForValue(obj)]
 
     #####################################################################
