@@ -180,6 +180,21 @@ class Script(web.Script):
         debug.println(debug.LEVEL_INFO, msg, True)
         default.Script.onChildrenAdded(self, event)
 
+    def onChildrenRemoved(self, event):
+        """Callback for object:children-changed:removed accessibility events."""
+
+        if self.utilities.isStaticTextLeaf(event.any_data):
+            msg = "CHROMIUM: Ignoring because child is static text leaf"
+            debug.println(debug.LEVEL_INFO, msg, True)
+            return
+
+        if super().onChildrenRemoved(event):
+            return
+
+        msg = "Chromium: Passing along event to default script"
+        debug.println(debug.LEVEL_INFO, msg, True)
+        default.Script.onChildrenRemoved(self, event)
+
     def onDocumentLoadComplete(self, event):
         """Callback for document:load-complete accessibility events."""
 
