@@ -552,6 +552,14 @@ class Script(default.Script):
         self._lastCommandWasMouseButton = False
         return super().consumesKeyboardEvent(keyboardEvent)
 
+    def consumesBrailleEvent(self, brailleEvent):
+        """Returns True if the script will consume this braille event."""
+
+        self._lastCommandWasCaretNav = False
+        self._lastCommandWasStructNav = False
+        self._lastCommandWasMouseButton = False
+        return super().consumesBrailleEvent(brailleEvent)
+
     # TODO - JD: This needs to be moved out of the scripts.
     def textLines(self, obj, offset=None):
         """Creates a generator that can be used to iterate document content."""
@@ -752,6 +760,7 @@ class Script(default.Script):
                 elif lastKey == "Up" and self._rewindSayAll(context):
                     return
                 elif not self._lastCommandWasStructNav:
+                    orca.emitRegionChanged(context.obj, context.currentOffset)
                     self.utilities.setCaretPosition(context.obj, context.currentOffset)
                     self.updateBraille(context.obj)
 
@@ -761,6 +770,8 @@ class Script(default.Script):
             return
 
         orca.setLocusOfFocus(None, context.obj, notifyScript=False)
+        orca.emitRegionChanged(
+            context.obj, context.currentOffset, context.currentEndOffset, orca.SAY_ALL)
         self.utilities.setCaretContext(context.obj, context.currentOffset)
 
     def inFocusMode(self):
@@ -909,6 +920,10 @@ class Script(default.Script):
             super().presentObject(obj, **args)
             return
 
+        if obj.getRole() == pyatspi.ROLE_STATUS_BAR:
+            super().presentObject(obj, **args)
+            return
+
         priorObj = args.get("priorObj")
         if self._lastCommandWasCaretNav or args.get("includeContext"):
             priorObj, priorOffset = self.utilities.getPriorContext()
@@ -1234,6 +1249,7 @@ class Script(default.Script):
 
         self.utilities.setCaretContext(newFocus, caretOffset)
         self.updateBraille(newFocus)
+        orca.emitRegionChanged(newFocus, caretOffset)
 
         if self.utilities.isContentEditableWithEmbeddedObjects(newFocus) \
            and not (newFocus.getRole() == pyatspi.ROLE_TABLE_CELL and newFocus.name):
@@ -1266,6 +1282,17 @@ class Script(default.Script):
             debug.println(debug.LEVEL_INFO, msg, True)
             contents = self.utilities.getLineContentsAtOffset(newFocus, 0)
             utterances = self.speechGenerator.generateContents(contents)
+        elif self.utilities.lastInputEventWasLineNav() and self.utilities.isZombie(oldFocus):
+            msg = "WEB: Last input event was line nav; oldFocus is zombie. Generating line contents."
+            debug.println(debug.LEVEL_INFO, msg, True)
+            contents = self.utilities.getLineContentsAtOffset(newFocus, caretOffset)
+            utterances = self.speechGenerator.generateContents(contents)
+        elif self.utilities.lastInputEventWasLineNav() and event \
+             and event.type.startswith("object:children-changed"):
+            msg = "WEB: Last input event was line nav and children changed. Generating line contents."
+            debug.println(debug.LEVEL_INFO, msg, True)
+            contents = self.utilities.getLineContentsAtOffset(newFocus, caretOffset)
+            utterances = self.speechGenerator.generateContents(contents)
         else:
             msg = "WEB: New focus %s is not a special case. Generating speech." % newFocus
             debug.println(debug.LEVEL_INFO, msg, True)
@@ -1472,11 +1499,29 @@ class Script(default.Script):
             debug.println(debug.LEVEL_INFO, msg, True)
             return True
 
+        if self.utilities.eventIsBrowserUINoise(event):
+            msg = "WEB: Ignoring event believed to be browser UI noise"
+            debug.println(debug.LEVEL_INFO, msg, True)
+            return True
+
         if not self.utilities.inDocumentContent(event.source):
             msg = "WEB: Event source is not in document content"
             debug.println(debug.LEVEL_INFO, msg, True)
             return False
 
+        obj, offset = self.utilities.getCaretContext(getZombieReplicant=False)
+        msg = "WEB: Context: %s, %i (focus: %s)" % (obj, offset, orca_state.locusOfFocus)
+        debug.println(debug.LEVEL_INFO, msg, True)
+
+        if not obj or self.utilities.isZombie(obj):
+            obj, offset = self.utilities.findFirstCaretContext(event.source, event.detail1)
+            if obj:
+                msg = "WEB: Event handled by updating locusOfFocus and context"
+                debug.println(debug.LEVEL_INFO, msg, True)
+                orca.setLocusOfFocus(event, obj, True)
+                self.utilities.setCaretContext(obj, offset)
+                return True
+
         if self._lastCommandWasCaretNav:
             msg = "WEB: Event ignored: Last command was caret nav"
             debug.println(debug.LEVEL_INFO, msg, True)
@@ -1543,8 +1588,9 @@ class Script(default.Script):
             self._presentTextAtNewCaretPosition(event)
             return True
 
-        if not self.utilities.queryNonEmptyText(event.source):
-            msg = "WEB: Event ignored: Was for object we're treating as textless"
+        if not self.utilities.queryNonEmptyText(event.source) \
+           and not event.source.getState().contains(pyatspi.STATE_EDITABLE):
+            msg = "WEB: Event ignored: Was for non-editable object we're treating as textless"
             debug.println(debug.LEVEL_INFO, msg, True)
             return True
 
@@ -1626,6 +1672,11 @@ class Script(default.Script):
             self.liveRegionManager.handleEvent(event)
             return True
 
+        if self.utilities.isLiveRegion(event.source):
+            msg = "WEB: Ignoring because live region event not to be handled."
+            debug.println(debug.LEVEL_INFO, msg, True)
+            return True
+
         if self._loadingDocumentContent:
             msg = "WEB: Ignoring because document content is being loaded."
             debug.println(debug.LEVEL_INFO, msg, True)
@@ -1707,6 +1758,37 @@ class Script(default.Script):
 
         return False
 
+    def onChildrenRemoved(self, event):
+        """Callback for object:children-changed:removed accessibility events."""
+
+        if not self.utilities.inDocumentContent(event.source):
+            msg = "WEB: Event source is not in document content."
+            debug.println(debug.LEVEL_INFO, msg, True)
+            return False
+
+        if self._loadingDocumentContent:
+            msg = "WEB: Ignoring because document content is being loaded."
+            debug.println(debug.LEVEL_INFO, msg, True)
+            return True
+
+        if self.utilities.handleEventForRemovedChild(event):
+            msg = "WEB: Event handled for removed child."
+            debug.println(debug.LEVEL_INFO, msg, True)
+            return True
+
+        # TODO - JD: Handle this case.
+        if event.source == orca_state.locusOfFocus:
+            msg = "WEB: Parent is locusOfFocus."
+            debug.println(debug.LEVEL_INFO, msg, True)
+            return False
+
+        if self.utilities.isLiveRegion(event.source):
+            msg = "WEB: Ignoring removal from live region."
+            debug.println(debug.LEVEL_INFO, msg, True)
+            return True
+
+        return False
+
     def onDocumentLoadComplete(self, event):
         """Callback for document:load-complete accessibility events."""
 
@@ -2124,6 +2206,11 @@ class Script(default.Script):
             self.liveRegionManager.handleEvent(event)
             return True
 
+        if self.utilities.isLiveRegion(event.source):
+            msg = "WEB: Ignoring because live region event not to be handled."
+            debug.println(debug.LEVEL_INFO, msg, True)
+            return True
+
         if self.utilities.eventIsEOCAdded(event):
             msg = "WEB: Ignoring: Event was for embedded object char"
             debug.println(debug.LEVEL_INFO, msg, True)
@@ -2188,6 +2275,11 @@ class Script(default.Script):
             debug.println(debug.LEVEL_INFO, msg, True)
             return True
 
+        if self.utilities.eventIsBrowserUINoise(event):
+            msg = "WEB: Ignoring event believed to be browser UI noise"
+            debug.println(debug.LEVEL_INFO, msg, True)
+            return True
+
         if not self.utilities.inDocumentContent(event.source):
             msg = "WEB: Event source is not in document content"
             debug.println(debug.LEVEL_INFO, msg, True)
